@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xml-hamlet
 version: 0.4.0.11
-id: xml-hamlet-0.4.0.11-098ca9d2f47bc93b0ee2115de1eed9c5
-key: xmlha_H23xm1yQYB10pcMn3dVpyg
+id: xml-hamlet-0.4.0.11-2e371055d7c311864bb01fac1a1a4b3c
+key: xmlha_23T96SjfuOD4dVyxeql3G4
 license: BSD3
 maintainer: michael@snoyman.com
 homepage: http://www.yesodweb.com/
@@ -20,15 +20,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-hamlet-0.4.0.11
-hs-libraries: HSxml-hamlet-0.4.0.11-H23xm1yQYB10pcMn3dVpyg
+hs-libraries: HSxml-hamlet-0.4.0.11-23T96SjfuOD4dVyxeql3G4
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
-    shakespeare-2.0.7-299569683f963ce6b42dbe4d7cdb1dae
+    shakespeare-2.0.7-d65cfe041713246ebadd86a7511ba6cd
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
-    xml-conduit-1.3.4-929e1b83c5cd543381c444e44eb0de12
+    xml-conduit-1.3.4-978b9ab149c55d47c395c4e421ee22a7
 haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
 haddock-html: /usr/share/doc/haskell-xml-hamlet/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
